@@ -79,8 +79,9 @@
 %    =>      copy one channel to another channel (e.g. red=>green)
 %    =       assign a constant value to a channel (e.g. red=50%)
 %    ,       write new image channels in the specified order (e.g. red, green)
-%    |       add a new output image for the next set of channel operations
-%    ;       move to the next input image for the source of channel data
+%    ;       add a new output image for the next set of channel operations
+%    |       move to the next input image for the source of channel data
+%             If there are no more images in the list, | has no effect.
 %
 %  For example, to create 3 grayscale images from the red, green, and blue
 %  channels of an image, use:
@@ -269,7 +270,6 @@ MagickExport Image *ChannelFxImage(const Image *image,const char *expression,
       }
       case '|':
       {
-        source_image=GetFirstImageInList(source_image);
         if (GetNextImageInList(source_image) != (Image *) NULL)
           source_image=GetNextImageInList(source_image);
         (void) GetNextToken(p,&p,MagickPathExtent,token);
@@ -411,7 +411,7 @@ MagickExport Image *ChannelFxImage(const Image *image,const char *expression,
             }
           }
         channel_mask=(ChannelType) (channel_mask |
-          (1UL << ParseChannelOption(token)));
+          (MagickLLConstant(1) << ParseChannelOption(token)));
         (void) GetNextToken(p,&p,MagickPathExtent,token);
         break;
       }
@@ -442,7 +442,7 @@ MagickExport Image *ChannelFxImage(const Image *image,const char *expression,
       case ExtractChannelOp:
       {
         channel_mask=(ChannelType) (channel_mask |
-          (1UL << destination_channel));
+          (MagickLLConstant(1) << destination_channel));
         destination_channel=(PixelChannel) (destination_channel+1);
         break;
       }
@@ -822,7 +822,7 @@ MagickExport Image *SeparateImage(const Image *image,
   }
   separate_view=DestroyCacheView(separate_view);
   image_view=DestroyCacheView(image_view);
-  (void) SetImageChannelMask(separate_image,DefaultChannels);
+  (void) SetImageChannelMask(separate_image,AllChannels);
   if (status == MagickFalse)
     separate_image=DestroyImage(separate_image);
   return(separate_image);
@@ -871,10 +871,10 @@ MagickExport Image *SeparateImages(const Image *image,ExceptionInfo *exception)
   {
     PixelChannel channel = GetPixelChannelChannel(image,i);
     PixelTrait traits = GetPixelChannelTraits(image,channel);
-    if (traits == UndefinedPixelTrait)
+    if ((traits == UndefinedPixelTrait) || ((traits & UpdatePixelTrait) == 0))
       continue;
-    separate_image=SeparateImage(image,(ChannelType) (1UL << channel),
-      exception);
+    separate_image=SeparateImage(image,(ChannelType)
+      (MagickLLConstant(1) << channel),exception);
     if (separate_image != (Image *) NULL)
       AppendImageToList(&images,separate_image);
   }
@@ -968,7 +968,7 @@ static inline void FlattenPixelInfo(const Image *image,const PixelInfo *p,
       }
       case AlphaPixelChannel:
       {
-        composite[i]=ClampToQuantum(QuantumRange*(Sa*(-Da)+Sa+Da));
+        composite[i]=ClampToQuantum((double) QuantumRange*(Sa*(-Da)+Sa+Da));
         break;
       }
       default:
@@ -1041,7 +1041,7 @@ MagickExport MagickBooleanType SetImageAlphaChannel(Image *image,
           ssize_t
             i;
 
-          gamma=QuantumScale*GetPixelAlpha(image,q);
+          gamma=QuantumScale*(double) GetPixelAlpha(image,q);
           for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
           {
             PixelChannel channel = GetPixelChannelChannel(image,i);
@@ -1050,7 +1050,7 @@ MagickExport MagickBooleanType SetImageAlphaChannel(Image *image,
               continue;
             if ((traits & UpdatePixelTrait) == 0)
               continue;
-            q[i]=ClampToQuantum(gamma*q[i]);
+            q[i]=ClampToQuantum(gamma*(double) q[i]);
           }
           q+=GetPixelChannels(image);
         }
@@ -1162,7 +1162,7 @@ MagickExport MagickBooleanType SetImageAlphaChannel(Image *image,
           ssize_t
             i;
 
-          Sa=QuantumScale*GetPixelAlpha(image,q);
+          Sa=QuantumScale*(double) GetPixelAlpha(image,q);
           gamma=PerceptibleReciprocal(Sa);
           for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
           {
@@ -1172,7 +1172,7 @@ MagickExport MagickBooleanType SetImageAlphaChannel(Image *image,
               continue;
             if ((traits & UpdatePixelTrait) == 0)
               continue;
-            q[i]=ClampToQuantum(gamma*q[i]);
+            q[i]=ClampToQuantum(gamma*(double) q[i]);
           }
           q+=GetPixelChannels(image);
         }
