@@ -738,7 +738,10 @@ static Image *ReadJXLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   JxlDecoderDestroy(jxl_info);
   if (jxl_status == JXL_DEC_ERROR)
     ThrowReaderException(CorruptImageError,"UnableToReadImageData");
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  if (status == MagickFalse)
+    return(DestroyImageList(image));
   return(GetFirstImageInList(image));
 }
 #endif
@@ -1053,10 +1056,13 @@ static MagickBooleanType WriteJXLImage(const ImageInfo *image_info,Image *image,
             *profile;
 
           profile=BlobToStringInfo("\0\0\0\6",4);
-          ConcatenateStringInfo(profile,exif_profile);
-          (void) JxlEncoderAddBox(jxl_info,"Exif",GetStringInfoDatum(profile),
-            GetStringInfoLength(profile),0);
-          profile=DestroyStringInfo(profile);
+          if (profile != (StringInfo *) NULL)
+            {
+              ConcatenateStringInfo(profile,exif_profile);
+              (void) JxlEncoderAddBox(jxl_info,"Exif",
+                GetStringInfoDatum(profile),GetStringInfoLength(profile),0);
+              profile=DestroyStringInfo(profile);
+            }
         }
       if (xmp_profile != (StringInfo *) NULL)
         {
@@ -1189,7 +1195,8 @@ static MagickBooleanType WriteJXLImage(const ImageInfo *image_info,Image *image,
   JxlEncoderDestroy(jxl_info);
   if (jxl_status != JXL_ENC_SUCCESS)
     ThrowWriterException(CoderError,"UnableToWriteImageData");
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   return(status);
 }
 #endif
